from dataclasses import dataclass, field
from typing import List, Optional
from .enums import City, CityArea, Category, Status


AREA_BY_CITY = {
    City.MOSCOW: [
        CityArea.NORTH_WEST, CityArea.EAST, CityArea.SOUTH,
        CityArea.TROITSKY, CityArea.WEST, CityArea.SOUTH_WEST,
        CityArea.NOVO_MOSCOW, CityArea.NORTH_EAST, CityArea.SOUTH_EAST,
        CityArea.NORTH, CityArea.CENTRAL
    ],
    City.ZELENOGRAD: [
        CityArea.ZELENOGRADSKIY
    ],
}

EMPTY_OBJECT_FILTER = {
    "category":      None,
    "city":          None,
    "cityArea":      None,
    "cityDistricts": None,
    "status":        None,
}


@dataclass
class ObjectFilter:
    category:       List[Category]       = field(default_factory=lambda: list(Category))
    city:           City                 = City.MOSCOW
    city_area:      Optional[List[CityArea]] = None
    city_districts: Optional[List[str]]  = None
    status:         List[Status]         = field(default_factory=lambda: list(Status))

    def __post_init__(self):
        if self.city_area is None:
            self.city_area = AREA_BY_CITY[self.city]

    def to_dict(self) -> dict:
        return {
            "category":      [c.value for c in self.category],
            "city":          self.city.value,
            "cityArea":      [a.value for a in self.city_area],
            "cityDistricts": self.city_districts,
            "status":        [s.value for s in self.status],
        }
